# robotframework-interpreter

Utility functions for building a Robot Framework interpreter.


# Acknowledgements

Most of the code was taken from the [robotkernel](https://github.com/robots-from-jupyter/robotkernel) Jupyter kernel. It has been extracted from this repository so it's easier to create other kernels with it.
